==> haskell-uniplate-1.6.13-261-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uniplate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uniplate
version:              1.6.13
visibility:           public
id:                   uniplate-1.6.13-A9LofKiYwag88a19tHTX3K
key:                  uniplate-1.6.13-A9LofKiYwag88a19tHTX3K
license:              BSD-3-Clause
copyright:            Neil Mitchell 2006-2020
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/uniplate#readme
synopsis:             Help writing simple, concise and fast generic operations.
description:
    Uniplate is library for writing simple and concise generic operations.
    Uniplate has similar goals to the original Scrap Your Boilerplate work,
    but is substantially simpler and faster.

    To get started with Uniplate you should import one of the three following
    modules:

    * "Data.Generics.Uniplate.Data" - to quickly start writing generic functions.
    Most users should start by importing this module.

    * "Data.Generics.Uniplate.Direct" - a replacement for "Data.Generics.Uniplate.Data"
    with substantially higher performance (around 5 times), but requires writing
    instance declarations.

    * "Data.Generics.Uniplate.Operations" - definitions of all the operations defined
    by Uniplate. Both the above two modules re-export this module.

    In addition, some users may want to make use of the following modules:

    * "Data.Generics.Uniplate.Zipper" - a zipper built on top of Uniplate instances.

    * "Data.Generics.SYB" - users transitioning from the Scrap Your Boilerplate library.

    * "Data.Generics.Compos" - users transitioning from the Compos library.

    * "Data.Generics.Uniplate.DataOnly" - users making use of both @Data@ and @Direct@
    to avoid getting instance conflicts.

category:             Generics
abi:                  d5ee944e1870eced04b9619353e65d3f
exposed:              True
exposed-modules:
    Data.Generics.Biplate Data.Generics.Compos Data.Generics.PlateData
    Data.Generics.PlateDirect Data.Generics.PlateTypeable
    Data.Generics.SYB Data.Generics.Str Data.Generics.Uniplate
    Data.Generics.Uniplate.Data Data.Generics.Uniplate.Data.Instances
    Data.Generics.Uniplate.DataOnly Data.Generics.Uniplate.Direct
    Data.Generics.Uniplate.Operations Data.Generics.Uniplate.Typeable
    Data.Generics.Uniplate.Zipper Data.Generics.UniplateOn
    Data.Generics.UniplateStr Data.Generics.UniplateStrOn

hidden-modules:
    Data.Generics.Uniplate.Internal.Data
    Data.Generics.Uniplate.Internal.DataOnlyOperations
    Data.Generics.Uniplate.Internal.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/uniplate-1.6.13
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uniplate-1.6.13
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uniplate-1.6.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uniplate
hs-libraries:         HSuniplate-1.6.13-A9LofKiYwag88a19tHTX3K
depends:
    base-4.17.2.1 containers-0.6.7 ghc-prim-0.9.1
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    syb-0.7.2.4-HJAbU0lurQkHN7nU4EHwhb
    unordered-containers-0.2.20-vB8Yx6KwyeBrT13JKFJ0i

haddock-interfaces:   /usr/share/doc/haskell-uniplate/html/uniplate.haddock
haddock-html:         /usr/share/doc/haskell-uniplate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uniplate-1.6.13-262-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uniplate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uniplate
version:              1.6.13
visibility:           public
id:                   uniplate-1.6.13-IrkhuyqUpN1CBGYTKzfHz3
key:                  uniplate-1.6.13-IrkhuyqUpN1CBGYTKzfHz3
license:              BSD-3-Clause
copyright:            Neil Mitchell 2006-2020
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/uniplate#readme
synopsis:             Help writing simple, concise and fast generic operations.
description:
    Uniplate is library for writing simple and concise generic operations.
    Uniplate has similar goals to the original Scrap Your Boilerplate work,
    but is substantially simpler and faster.

    To get started with Uniplate you should import one of the three following
    modules:

    * "Data.Generics.Uniplate.Data" - to quickly start writing generic functions.
    Most users should start by importing this module.

    * "Data.Generics.Uniplate.Direct" - a replacement for "Data.Generics.Uniplate.Data"
    with substantially higher performance (around 5 times), but requires writing
    instance declarations.

    * "Data.Generics.Uniplate.Operations" - definitions of all the operations defined
    by Uniplate. Both the above two modules re-export this module.

    In addition, some users may want to make use of the following modules:

    * "Data.Generics.Uniplate.Zipper" - a zipper built on top of Uniplate instances.

    * "Data.Generics.SYB" - users transitioning from the Scrap Your Boilerplate library.

    * "Data.Generics.Compos" - users transitioning from the Compos library.

    * "Data.Generics.Uniplate.DataOnly" - users making use of both @Data@ and @Direct@
    to avoid getting instance conflicts.

category:             Generics
abi:                  f4c692d6b81625b3f16e49bec0d4da8c
exposed:              True
exposed-modules:
    Data.Generics.Biplate Data.Generics.Compos Data.Generics.PlateData
    Data.Generics.PlateDirect Data.Generics.PlateTypeable
    Data.Generics.SYB Data.Generics.Str Data.Generics.Uniplate
    Data.Generics.Uniplate.Data Data.Generics.Uniplate.Data.Instances
    Data.Generics.Uniplate.DataOnly Data.Generics.Uniplate.Direct
    Data.Generics.Uniplate.Operations Data.Generics.Uniplate.Typeable
    Data.Generics.Uniplate.Zipper Data.Generics.UniplateOn
    Data.Generics.UniplateStr Data.Generics.UniplateStrOn

hidden-modules:
    Data.Generics.Uniplate.Internal.Data
    Data.Generics.Uniplate.Internal.DataOnlyOperations
    Data.Generics.Uniplate.Internal.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/uniplate-1.6.13
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uniplate-1.6.13
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uniplate-1.6.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uniplate
hs-libraries:         HSuniplate-1.6.13-IrkhuyqUpN1CBGYTKzfHz3
depends:
    base-4.17.2.1 containers-0.6.7 ghc-prim-0.9.1
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    syb-0.7.2.4-HJAbU0lurQkHN7nU4EHwhb
    unordered-containers-0.2.20-7moq3V15ycBgVs1tpEAw

haddock-interfaces:   /usr/share/doc/haskell-uniplate/html/uniplate.haddock
haddock-html:         /usr/share/doc/haskell-uniplate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
